@@ -1,5 +1,8 @@
 use core::fmt;
-use std::fmt::{Display, Formatter};
+use std::{
+    fmt::{Display, Formatter},
+    io::Write,
+};
 
 #[cfg(test)]
 mod tests {
@@ -8,15 +11,18 @@ mod tests {
     use super::Line;
 
     #[test]
-    fn default_line_is_printed_correctly() {
-        let output = String::new();
-
-        let line = Line::new(String::from("test"), '>');
-
-        // line.fmt(&mut output.fmt(f));
+    fn selected_line_printed_with_pointer() {
+        let mut line = Line::new(String::from("test"), '>');
+        line.select();
+        assert_eq!(line.draw(), "> test")
+    }
+    #[test]
+    fn unselected_line_printed_without_pointer() {
+        let mut line = Line::new(String::from("test"), '>');
+        assert_eq!(line.draw(), "  test")
     }
 }
-
+#[derive(Debug)]
 pub struct Line {
     text: String,
     is_selected: bool,
@@ -41,12 +47,12 @@ impl Line {
         self.is_selected = true;
     }
     pub fn underline(&mut self) {
-        self.text = format!("[4m{}[0m", self.text);
+        self.underline = true;
     }
     pub fn space_from_pointer(&mut self, space: usize) {
         self.space = space;
     }
-    /// set all changes made after creation back to default
+    /// set all changes back to default that were made after creation
     pub fn default(&mut self) {
         self.is_selected = false;
         self.space = 1;
@@ -56,13 +62,15 @@ impl Line {
     fn underline_text(&self, text: &str) -> String {
         format!("[4m{}[0m", text)
     }
-    pub fn len(&self) -> usize {
-        self.text.chars().count() + 2
+    fn underline_if_required(&mut self, text: &str) {
+        if self.underline {
+            self.text = format!("[4m{}[0m", text);
+        }
     }
-}
-
-impl Display for Line {
-    fn fmt(&self, f: &mut Formatter) -> fmt::Result {
+    pub fn len(&self) -> usize {
+        self.text.chars().count() + self.space + 1
+    }
+    fn draw(&self) -> String {
         let text = if self.underline {
             Some(self.underline_text(&self.text))
         } else {
@@ -70,12 +78,19 @@ impl Display for Line {
         };
         let pointer = if self.is_selected { self.pointer } else { ' ' };
 
-        f.write_str(&format!(
+        format!(
             "{}{}{}",
             pointer,
             " ".repeat(self.space),
             text.as_ref().unwrap_or(&self.text),
-        ))?;
+        )
+    }
+}
+
+impl Display for Line {
+    fn fmt(&self, f: &mut Formatter) -> fmt::Result {
+        print!("{}", self.draw());
+        std::io::stdout().flush();
         Ok(())
     }
 }
